@@ -606,6 +606,8 @@ class PreparedDocument:
 		self._doc = doc
 		self._session = session
 
+		self._corpus = corpus
+
 		storage = doc.storage
 		self._metadata = storage.metadata
 
@@ -645,6 +647,14 @@ class PreparedDocument:
 	def doc(self):
 		return self._doc
 
+	@property
+	def corpus(self):
+		return self._corpus
+
+	@property
+	def corpus_id(self):
+		return self._corpus.get_unique_id(self._doc)
+
 	@property
 	def session(self):
 		return self._session
@@ -668,10 +678,6 @@ class PreparedDocument:
 	def metadata(self):
 		return self._metadata
 
-	@property
-	def unique_id(self):
-		return self._doc.unique_id
-
 	@contextlib.contextmanager
 	def text(self):
 		with self.storage.text() as text:
